@@ -9,7 +9,7 @@ fn main() {
         Ok(scanner) => (scanner),
         Err(e) => panic!("Error creating scanner: {}", e),
     };
-    port_scanner.set_target_ipaddr("192.168.1.8");
+    port_scanner.set_target_ipaddr("192.168.1.1");
     port_scanner.set_range(1, 1000);
     //port_scanner.add_target_port(22);
     //port_scanner.add_target_port(80);
@@ -21,7 +21,7 @@ fn main() {
     let result = port_scanner.get_result();
     print!("Status: ");
     match result.scan_status {
-        ScanStatus::Done => {println!("Normal end")},
+        ScanStatus::Done => {println!("Done")},
         ScanStatus::Timeout => {println!("Timed out")},
         _ => {println!("Error")},
     }
