@@ -17,14 +17,8 @@ pub fn build_tcp_packet(tcp_packet:&mut pnet::packet::tcp::MutableTcpPacket, src
         PortScanType::SynScan => {
             tcp_packet.set_flags(pnet::packet::tcp::TcpFlags::SYN);
         },
-        PortScanType::FinScan => {
-            tcp_packet.set_flags(pnet::packet::tcp::TcpFlags::FIN);
-        },
-        PortScanType::XmasScan => {
-            tcp_packet.set_flags(pnet::packet::tcp::TcpFlags::FIN | pnet::packet::tcp::TcpFlags::URG | pnet::packet::tcp::TcpFlags::PSH);
-        },
-        PortScanType::NullScan => {
-            tcp_packet.set_flags(0);
+        _ => {
+            tcp_packet.set_flags(pnet::packet::tcp::TcpFlags::SYN);
         },
     }
     let checksum = pnet::packet::tcp::ipv4_checksum(&tcp_packet.to_immutable(), &src_ip_addr, &dst_ip_addr);
